@@ -7,7 +7,7 @@ import json
 
 import requests
 
-from munzee.endpoints import Munzees, Players
+from munzee.endpoints import Clans, Map, Munzees, Players
 
 
 class Munzee:
@@ -23,6 +23,8 @@ class Munzee:
         self.base_requester = self.Requester(self._api_key)
         self.users = Players(self.base_requester)
         self.munzees = Munzees(self.base_requester)
+        self.map = Map(self.base_requester)
+        self.clans = Clans(self.base_requester)
 
     class Requester(object):
         """Api requesting object"""
